@@ -1,19 +1,18 @@
-plot.hqreg <- function(x, xvar = c("lambda", "norm"), log.x =FALSE, nvars = TRUE, alpha = 1, ...)
+plot.hqreg <- function(x, xvar = c("lambda", "norm"), log.l = TRUE, nvars = TRUE, alpha = 1, ...)
 {
   xvar <- match.arg(xvar)
-  if (xvar == "norm" && log.x == TRUE) stop("set log.x to be FALSE when plotting against the L1 norm")
   nonzero <- which(rowSums(abs(x$beta))!=0)
   Y <- x$beta[nonzero[-1],]
   p <- nrow(Y)
   if (xvar == "lambda") {
     X <- x$lambda
-    if (log.x) X <- log(X)
+    if (log.l) X <- log(X)
   } else {
     X <- colSums(abs(Y))
   }
   
   if (xvar == "lambda") {
-    xlab <- if (log.x) expression(log(lambda)) else expression(lambda)
+    xlab <- if (log.l) expression(log(lambda)) else expression(lambda)
     xlim <- rev(range(X))
   } else {
     xlab <- expression(group("||", hat(beta), "||")[1])
